from setuptools import setup, find_packages

import djcroco


setup(
    name='django-croco',
    packages=find_packages(),
    include_package_data=True,
    version='0.4.2',
    description='',
    long_description=open('README.rst').read(),
    author=djcroco.__author__,
    url='https://github.com/incuna/django-croco/',
    install_requires=[
        'crocodoc',
    ],
    zip_safe=False,
)



from django.db import models

from djcroco.fields import CrocoField


class Example(models.Model):
    name = models.CharField(max_length=255)
    document = CrocoField(thumbnail_field='my_thumbnail')
    my_thumbnail = models.ImageField(upload_to='whatever/')

    def __unicode__(self):
        return self.name

class NullableExample(models.Model):
    name = models.CharField(max_length=255)
    document = CrocoField(null=True)

    def __unicode__(self):
        return self.name
